"""Auto-generated stub for module: h265_auto."""
from typing import Any

from .h265_processor import H265FrameEncoder, H265FrameDecoder
from .h265_processor import H265FrameEncoder, H265FrameDecoder
from .h265_processor_linux import H265PersistentFrameEncoder, H265PersistentFrameDecoder

# Constants
IS_LINUX: Any
logger: Any
